#
# spec file for package OpenBoard
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         dest_dir %{_libdir}/%{name}
%define         namelc openboard
%define         fqname ch.%{namelc}.%{name}
Name:           OpenBoard
Version:        1.7.3
Release:        1
Summary:        Interactive whiteboard for schools and universities
License:        GPL-3.0-or-later
Group:          Amusements/Teaching/Other
URL:            https://openboard.ch
Source0:        https://github.com/OpenBoard-org/OpenBoard/archive/v%{version}.tar.gz#/%{name}-1.7.3.tar.gz

#Patch569:       0569-scale-mirror-pixmap.patch
#Patch686:       0686-shortcut-configuration.patch
#Patch698:       0698-add-cmake-build-system.patch
#Patch9117:      9117-disable-software-update.patch
#Patch9686:      9686-cmake-add-shortcut-manager.patch

BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Multimedia)
BuildRequires:  cmake(Qt6MultimediaWidgets)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6UiTools)
BuildRequires:  cmake(Qt6WebEngineWidgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(poppler-cpp)
BuildRequires:  pkgconfig(quazip1-qt6)
Recommends:     onboard

%description
OpenBoard is an open source cross-platform interactive white board
application designed primarily for use in schools. It was
originally forked from Open-Sankoré, which was itself based on
Uniboard.

This build is based on the development branch dev and includes
a set of additional patches for features and bug fixes.

%prep
%autosetup -p1 -n OpenBoard-1.7.3

# remove x flag from any resource files
find resources -type f -print0 | xargs -0 chmod a-x

# remove leftover git file
#rm resources/library/applications/Calculator.wgt/.gitignore

%build
%cmake -DQT_VERSION=6 
%cmake_build

%install
%cmake_install

%fdupes -s %{buildroot}

%files
%license LICENSE
%doc COPYRIGHT
%{_datadir}/applications/%{fqname}.desktop
%{_datadir}/icons/hicolor/scalable
%{_datadir}/mime/packages/*
%{_datadir}/%{namelc}
%{_bindir}/%{namelc}
%config %{_sysconfdir}/%{namelc}

%changelog
* Thu Jan 2 2025 Marie Loise Nolden <loise@kde.org> - 1.7.3-1
- update to 1.7.3

* Tue Jun 13 2023 Martin Winter <me@letsfindaway.de>
- update to version 1.7.0a+230613
  * remove upstreamed patches
  * minor bug fixes
- remove upstreamed patches
  * remove 0762-widget-camera.patch
  * remove 0750-fix-scaled-pdf.patch
* Thu May 11 2023 Martin Winter <me@letsfindaway.de>
- update to version 1.7.0a+230511
- update camera widget
  * update 0762-widget-camera.patch
  * improved GUI
* Sun May  7 2023 Martin Winter <me@letsfindaway.de>
- update to version 1.7.0a+230507
  * remove upstreamed patches
  * update camera widget
- remove upstreamed patches
  * remove 0745-fix-sync-onboard-state.patch
  * remove 0758-perf-image-formats.patch
- update camera widget
  * replace 0757-widget-camera.patch by 0762-widget-camera.patch
    add option for image rotation
* Wed Apr 19 2023 Martin Winter <me@letsfindaway.de>
- update 0758-perf-image-formats.patch
* Sun Apr 16 2023 Martin Winter <me@letsfindaway.de>
- replace patch
  * replace 0746-fix-image-rotation.patch
    by 0758-perf-image-formats.patch
    store images in their original format
- update patch
  * update 0757-widget-camera.patch
    transfer snapshot images in JPEG format
* Fri Apr 14 2023 Martin Winter <me@letsfindaway.de>
- fixed spec file
* Fri Apr 14 2023 Martin Winter <me@letsfindaway.de>
- update to version 1.7.0a+230414
  * bug fixes
- remove upstreamed patches
  * remove 0677-pdf-export-page-size.patch
- add new patches
  * add 0745-fix-sync-onboard-state.patch
    sync onboard visibility when onboard was externally shown or hidden
  * add 0746-fix-image-rotation.patch
    respect image rotation from EXIF metadata
  * add 0750-fix-scaled-pdf.patch
    next try to fix PDF export scaling
  * add 0757-widget-camera.patch
    widget for live camera image on board
* Fri Mar 24 2023 Martin Winter <me@letsfindaway.de>
- update to version 1.7.0a+230314
  * add favorite documents
  * add startup hints
  * bug fixes
- remove upstreamed patches
  * remove 0551-common-background-drawing.patch
* Sat Jan 14 2023 Martin Winter <me@letsfindaway.de>
- update ffmpeg dependencies for Ubuntu / Debian
* Tue Nov 29 2022 Martin Winter <me@letsfindaway.de>
- update to version 1.7.0a+1129
  * add PDF export options to preferences UI
  * minor fixes
- disable software update
  * don't ask openboard.org for new software versions
* Mon Nov 14 2022 Martin Winter <me@letsfindaway.de>
- update to version 1.7.0a+1114
  * remove obsolete edumedia handling
  * open target=_blank links in widgets in same view
  * workaround for QTBUG-108284 with CSS styled cursors
- feature: shortcut configuration
  * rebase patch on current dev
- remove upstreamed patches
  * remove 0689-duplicate-files.patch
  * remove 0690-transparent-widget-background.patch
  * remove 0694-fix-pdf-dnd-import.patch
- update cmake build system
* Sun Oct 30 2022 Martin Winter <me@letsfindaway.de>
- fix: re-add missing translations
* Sun Oct 30 2022 Martin Winter <me@letsfindaway.de>
- fix: adapt cmake for Qt 5.12 needed for Leap 15.3 and Ubuntu 20.04
* Sat Oct 29 2022 Martin Winter <me@letsfindaway.de>
- update to version 1.7.0a+1029
- fix: common background drawing
  * update 0551-common-background-drawing.patch
- fix: scale mirror pixmap
  * update 0569-scale-mirror-pixmap.patch
- remove upstreamed patches
  * remove 0604-qt-5.12-compatibility.patch
  * remove 0629-bug-ruler.patch
  * remove 0633-improve-displaymanager.patch
  * remove 0637-fix-pdf-background-export.patch
  * remove 0641-fix-font-handling.patch
  * remove 0649-fix-pdf-export-scaling.patch
- switch to cmake based build system
  * remove 0651-chore-reorganize-linux-build.patch
  * add 0698-add-cmake-build-system.patch
- fix: pdf export page size
  * add 0677-pdf-export-page-size.patch
- feature: shortcut configuration
  * remove 0460-shortcut-configuration.patch
  * add 0686-shortcut-configuration.patch, supersedes 0460
  * add 9686-cmake-add-shortcut-manager.patch
- fix: duplicate files
  * add 0689-duplicate-files.patch
- fix: transparent widget background
  * add 0690-transparent-widget-background.patch
- fix: PDF import using DnD
  * add 0694-fix-pdf-dnd-import.patch
* Tue Sep 20 2022 Martin Winter <me@letsfindaway.de>
- fix file list in spec file
  - do not include /usr/share/mime/packages directory owned by
    filesystem
* Tue Sep 13 2022 Martin Winter <me@letsfindaway.de>
- updated patches
  - 0633: minor refactoring
  - 0637: fix PDF export with PDF background document
  - 0641: chore: rebased
  - 0649: chore: rebased, compatibility with 1.6.x and 1.7.x
  - 0651: fix onboard DBus handling
* Wed Jul 13 2022 Martin Winter <me@letsfindaway.de>
- improve usage of onboard
  - add Recommends: onboard
  - show/hide onboard using DBus messages
* Thu Jul  7 2022 Martin Winter <me@letsfindaway.de>
- use reorganized Linux build patch
  - 0651-chore-reorganize-linux-build.patch
* Fri Jul  1 2022 Martin Winter <me@letsfindaway.de>
- fix PDF export
  - 0649-fix-pdf-export-scaling.patch
* Fri Jun 24 2022 Martin Winter <me@letsfindaway.de>
- fix font handling
  - improve performance when building font list
    add 0641-fix-font-handling.patch
  - package fonts
    add 0008-install-fonts.patch
* Wed Jun 22 2022 Martin Winter <me@letsfindaway.de>
- update 0633-improve-displaymanager.patch
- add 0637-fix-pdf-background-export.patch
- update debian build files
* Sun Jun 19 2022 Martin Winter <me@letsfindaway.de>
- add patch 0629-bug-ruler.patch to fix bug in ruler handling
* Fri Jun 17 2022 Martin Winter <me@letsfindaway.de>
- update to 1.7-dev as of 08.06.2022
- remove patches 0465, 0546, 0573 merged upstream
- add patch 0604 to maintain compatibility with Qt 5.12
- add patch 0633 to improve display manager
* Sat Mar 26 2022 Martin Winter <me@letsfindaway.de>
- update to 1.7-dev as of 25.03.2022
- remove patches 0533 and 0545 merged upstream
- update several other patches
* Fri Mar 11 2022 Martin Winter <me@letsfindaway.de>
- compile with poppler 22.03
* Tue Feb  1 2022 Martin Winter <martin@winter-rosenheim.de>
- update to up-to-date 1.7-dev
- fix crash on exit
* Sat Jan 29 2022 Martin Winter <martin@winter-rosenheim.de>
- add patch to use std=c++17 for pdf/libpoppler
* Tue Jan  4 2022 Martin Winter <martin@winter-rosenheim.de>
- add patches for PRs 465, 533 and 546
* Tue Jan  4 2022 Martin Winter <martin@winter-rosenheim.de>
- update shortcut-configuration patch
* Tue Jan  4 2022 Martin Winter <martin@winter-rosenheim.de>
- another fix for patch for QWebEngine < 5.13
* Sun Jan  2 2022 Martin Winter <martin@winter-rosenheim.de>
- fix patch for QWebEngine < 5.13
* Sun Jan  2 2022 Martin Winter <martin@winter-rosenheim.de>
- add dependency Qt5Concurrent to spec file
* Sun Jan  2 2022 Martin Winter <martin@winter-rosenheim.de>
- add webengine-improvements
* Sun Jan  2 2022 Martin Winter <martin@winter-rosenheim.de>
- add dependency libfontconfig1-dev
* Tue Oct 26 2021 Martin Winter <martin@winter-rosenheim.de>
- Update sources
- Add Ubuntu build scripts
* Sat Aug 28 2021 Martin Winter <martin@winter-rosenheim.de>
- Status of pull request after completing known tasks
* Fri Aug  6 2021 Martin Winter <martin@winter-rosenheim.de>
- Status of initial pull request to OpenBoard
  - Fix freezing
  - Open link in external browser
* Sun Aug  1 2021 Martin Winter <martin@winter-rosenheim.de>
- Widget apps updated
* Mon May 24 2021 Martin Winter <martin@winter-rosenheim.de>
- Experimental build with QWebEngine
* Sat Mar 20 2021 Martin Winter <martin@winter-rosenheim.de>
- Create patch from squashed commit
- Add German translation for shortcut configuration
* Thu Mar 18 2021 Martin Winter <martin@winter-rosenheim.de>
- reordered includes
* Thu Mar 18 2021 Martin Winter <martin@winter-rosenheim.de>
- minor fixes and refactoring
* Wed Mar 17 2021 Martin Winter <martin@winter-rosenheim.de>
- Update to 1.6.1rc-0309
- Add configurable shortcuts
* Mon Mar  8 2021 Martin Winter <martin@winter-rosenheim.de>
- Update to dev-qt5.1x of 08.03.2021
- Remove upstreamed patches
* Tue Mar  2 2021 Martin Winter <martin@winter-rosenheim.de>
- Update label color when background changes
* Tue Mar  2 2021 Martin Winter <martin@winter-rosenheim.de>
- Add patches for upstream issues #430 and #444
* Sat Feb 27 2021 Martin Winter <martin@winter-rosenheim.de>
- Update to newest development branch
- make tools disabled by default (request from upstream)
- fix shortcuts with German translation
* Sun Feb 21 2021 Martin Winter <martin@winter-rosenheim.de>
- many improvements, e.g.
  + better tool icon
  + improved position handling
  + fixed persistence
* Wed Feb 17 2021 Martin Winter <martin@winter-rosenheim.de>
- add patch to draw intermediate grid lines
* Sun Feb 14 2021 Martin Winter <martin@winter-rosenheim.de>
- update version check in spec file for Leap 15.3
* Sun Feb 14 2021 Martin Winter <martin@winter-rosenheim.de>
- update to 1.6.1rc from dev-qt5.1x branch
- 0010-Add-axes-tool.patch
  + move own additions to patch file
- OpenBoard-tool-axes.tgz
  + icon for axes tool
* Fri Feb 12 2021 Martin Winter <martin@winter-rosenheim.de>
- update to 1.6.1
- 0001-Rewrite-libs.pri.patch:
  + adapt to 1.6.1
- 0002-Use-libpoppler-instead-of-raw-xpdf.patch:
  + remove, upstreamed
- 0009-Fix-finding-QWebView.patch:
  + remove, upstreamed
- add axes tool for drawing coordinate systems
  + add feature to switch numbering on/off
* Mon Feb  8 2021 Adam Majer <adam.majer@suse.de>
- Compile translations so they are installed (bsc#1181857)
* Mon Nov 23 2020 Adam Majer <adam.majer@suse.de>
- 0001-Rewrite-libs.pri.patch:
  + update patch and BR on now weirdly named quazip - pkgconfig(quazip1-qt5)
  + continue to function with with pkgconfig(quazip) in Leap 15.2
- Remove BR on libx264-devel and fdk-aac-devel as these are no longer
  available in Factory
* Sat May 23 2020 Frank Schütte <F.Schuette@t-online.de>
- fixed building with patches from https://github.com/flathub/ch.openboard.OpenBoard
* Fri May 22 2020 Frank Schütte <F.Schuette@t-online.de>
- update to 1.5.4
* Mon Jun 10 2019 Frank Schütte <F.Schuette@t-online.de>
- remove openssl patch
* Mon Jun 10 2019 Frank Schütte <F.Schuette@t-online.de>
- Update to OpenBoard 1.5.3
- updated OpenBoard-no-Third-Party patch
* Fri Jan 25 2019 F.Schuette@t-online.de
- Update to OpenBoard 1.5.2
* Tue Sep 11 2018 F.Schuette@t-online.de
- Update to OpenBoard 1.4.1
  * Add patch for ffmpeg includes.
* Wed Jan 10 2018 antoine.belvire@opensuse.org
- Add compatibility with OpenSSL 1.1 API:
  * OpenBoard-1.3.6-add-openssl-1.1-compat.patch.
  * Authorize build with OpenSSL 1.1 by removing version constraint
    on "BuildRequires".
- Merge quazip_libname.patch with OpenBoard-no_Third-Party.patch.
* Tue Jan  9 2018 antoine.belvire@opensuse.org
- Update to version 1.3.6:
  * Fix several issues relating to copy-pasting and
    cut-and-pasting elements from one page or document to another.
  * Fix an issue where pen strokes that had been erased with the
    eraser would reappear after saving and loading.
  * Fix an issue where duplicating a pen stroke that had been
    moved could cause the new stroke to be placed in the wrong
    position.
  * Fix an issue where strokes could be badly placed after using
    the "undo" and "redo" functions.
  * Fix an issue where compass strokes were not saved (when
    making several strokes, only the first one was saved).
  * Fix an issue where pages could be truncated when exporting to
    PDF.
  * Fix an issue where locked items could be moved when part of a
    multiple selection
  * (Document mode) Fix document selection after deleting a
    trashed document.
  * Tweak the background grid color for the dark background.
  * The mask tool can now be resized non-proportionately.
  * Re-implemented automatic update checking, which will appear
    to users when the next version is released.
- Changes from version 1.3.5:
  * Fix detection of "cloned" multi-monitor setups to avoid
    multi-screen mode being activated in this configuration.
    [Note: some problems remain with multi-monitor setups on some
    Linux versions.].
  * Text items: Text can no longer be selected or edited if the
    text item is marked as non-editable through its menu.
  * Text items: On page load, text items no longer take keyboard
    focus.
  * Library pane: Fix moving of items (upon moving an item to a
    folder, the item would not immediately disappear from its
    current location).
  * Library pane: Fix nested folder issue in breadcrumbs trail (two
    folders that were at the same path and whose names started with
    the same characters were considered by the breadcrumbs trail to
    be nested).
  * Document view: Fix folder names not being saved after renaming
    them.
  * Fix audio item saving (v1.3.3 bug): Documents containing an
    audio item were saved incorrectly, making the audio unplayable
    upon page load.
  * Desktop mode: Eraser and marker preview circles now disappear
    when the cursor hovers over the left or right-hand toolbars, as
    in board mode.
- Drop OpenBoard-fix-call-of-overloaded-abs-is-ambiguous.patch
  (fixed upstream).
- Fix some rpmlint warnings.
* Tue Jan  9 2018 antoine.belvire@opensuse.org
- Fix build:
  * Change OpenBoard-XPDFRenderer_with_poppler.patch to make it
    work with libpoppler >= 0.55.
  * Force use of OpenSSL 1.0 as build requirement instead of 1.1.
  * Use "libquazip-qt5-devel" instead of "quazip-qt5-devel" in
    build requirements to fix build on Leap.
* Fri Jun 30 2017 adam.majer@suse.de
- quazip_libname.patch: Use quazip-qt5 instead of quazip as mixing
  Qt versions is bad. Qt5 quazip also uses a different library
  name. (boo#1042040)
- add missing libpulse BuildRequires
* Mon Feb 13 2017 mrueckert@suse.de
- update to 1.3.4
  - OS X: fixed desktop drop shadow bug: when switching from
    desktop mode to board mode and back, shadows were drawn behind
    annotations; these persisted even if the annotation was erased
  - Windows: Updated bundled Visual C++ runtime library; fixed
    installer so that the library installation would be silent (no
    more dialog box appearing)
  - Linux: fixed detection of "cloned" multi-monitor setups to
    avoid multi-screen mode being activated in this configuration.
    [Note: some problems remain with multi-monitor setups on some
    Linux versions; see Known Issues]
  - Text items: text can no longer be selected or edited if the
    text item is marked as non-editable through its menu
  - Text items: on page load, text items no longer take keyboard
    focus
  - Library pane: fixed moving of items (upon moving an item to a
    folder, the item would not immediately disappear from its
    current location)
  - Library pane: fixed nested folder issue in breadcrumbs trail
    (two folders that were at the same path and whose names started
    with the same characters were considered by the breadcrumbs
    trail to be nested)
  - Document view: fixed folder names not being saved after
    renaming them
  - Fixed audio item saving (v1.3.3 bug): documents containing an
    audio item were saved incorrectly, making the audio unplayable
    upon page load
  - Desktop mode: eraser and marker preview circles now disappear
    when the cursor hovers over the left or right-hand toolbars, as
    in board mode
- refreshed OpenBoard-XPDFRenderer_with_poppler.patch to apply
  cleanly again
